@@ -13,5 +13,5 @@ baz <- function() {
 }
 
 if (winch_available() && requireNamespace("purrr")) {
-  foo()
+  tryCatch(foo(), error = identity)
 }
